import { ComponentRegister } from '@core/pipeline';
import { ItemTemplate, RootObject } from '../../income';
export interface IPipeline {
    Run(): Promise<any>;
}
/**
 * Represents a Pipeline which runs multiple components
 */
export declare abstract class Pipeline implements IPipeline {
    protected name: string;
    protected input: RootObject;
    protected _components: ComponentRegister[];
    protected parsedInput: ItemTemplate[];
    private sortedComponents;
    private visitedComponents;
    /**
     * Creates a new pipeline and parses the input by calling
     * `isItemTemplate`
     * @param input The GAME_MASTER data
     * @param name The name of the pipeline
     */
    constructor(input: RootObject, name: string);
    readonly Components: ComponentRegister[];
    abstract isItemTemplate(item: ItemTemplate): boolean;
    Parse(): ItemTemplate[];
    /**
     * Checks the dependencies of the given component-register
     * @param component The component-register to check the dependencies
     * @param ancestors (optional) Its parent ids
     */
    private visitComponent;
    /**
     * Sorts the components so it is executed with correct dependency relation.
     * Will be stored inside `this.sortedComponents`
     */
    private resolveDependencyResolution;
    private process;
    private shouldComponentBeProcessed;
    private processSimpleMapComponent;
    /**
     * Runs the components of its Pipeline
     */
    Run(): Promise<Object[]>;
}
