"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
Object.defineProperty(exports, "__esModule", { value: true });
var pipeline_1 = require("@core/pipeline");
var p_iteration_1 = require("p-iteration");
/**
 * Represents a Pipeline which runs multiple components
 */
var Pipeline = /** @class */ (function () {
    /**
     * Creates a new pipeline and parses the input by calling
     * `isItemTemplate`
     * @param input The GAME_MASTER data
     * @param name The name of the pipeline
     */
    function Pipeline(input, name) {
        this.input = input;
        this.name = name;
        this.parsedInput = this.Parse();
    }
    Object.defineProperty(Pipeline.prototype, "Components", {
        get: function () {
            var _this = this;
            if (!this._components) {
                this._components = pipeline_1.ComponentRegistry.Instance.Components.filter(function (component) { return component.settings.pipeline === _this.name; });
            }
            return this._components;
        },
        enumerable: true,
        configurable: true
    });
    Pipeline.prototype.Parse = function () {
        var _this = this;
        return this.input.itemTemplates
            .filter(function (p) { return _this.isItemTemplate(p); });
    };
    /**
     * Checks the dependencies of the given component-register
     * @param component The component-register to check the dependencies
     * @param ancestors (optional) Its parent ids
     */
    Pipeline.prototype.visitComponent = function (component, ancestors) {
        var _this = this;
        if (ancestors === undefined) {
            ancestors = [];
        }
        ancestors.push(component.id);
        this.visitedComponents[component.id] = true;
        component.dependencies.forEach(function (dependency) {
            // @ts-ignore
            var dependencyId = dependency.constructor.name;
            if (ancestors.indexOf(dependencyId) >= 0) // if already in ancestors, a closed chain exists.
                throw new Error("Circular dependency \"" + dependencyId + "'\" is required by \"" + component.id + "\": " + ancestors.join(' -> '));
            // if already exists, do nothing
            if (_this.visitedComponents[component.id])
                return;
            _this.visitComponent(dependency, ancestors.slice(0)); // recursive call
        });
        this.sortedComponents.push(component);
    };
    /**
     * Sorts the components so it is executed with correct dependency relation.
     * Will be stored inside `this.sortedComponents`
     */
    Pipeline.prototype.resolveDependencyResolution = function () {
        var _this = this;
        this.sortedComponents = [];
        this.visitedComponents = {};
        this.Components.forEach(function (component) { return _this.visitComponent(component); });
    };
    Pipeline.prototype.process = function (component, output, input) {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, new Promise(function (resolve, reject) {
                        var callback;
                        try {
                            // Synchronous
                            callback = component.component.Process(output, input);
                        }
                        catch (error) {
                            reject(error);
                        }
                        if (callback && callback.then) {
                            // Is async
                            callback.then(resolve).catch(reject);
                        }
                        else {
                            resolve(callback);
                        }
                    })];
            });
        });
    };
    Pipeline.prototype.shouldComponentBeProcessed = function (component, input) {
        // No templateId settings was set (= allow every item template)
        return !component.settings.templateId ||
            // or is actually correct template id
            input.templateId === component.settings.templateId;
    };
    Pipeline.prototype.processSimpleMapComponent = function (component, output) {
        return __awaiter(this, void 0, void 0, function () {
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, p_iteration_1.mapSeries(this.parsedInput, function (input, index) { return __awaiter(_this, void 0, void 0, function () {
                            var processedItem;
                            return __generator(this, function (_a) {
                                switch (_a.label) {
                                    case 0:
                                        processedItem = output[index] || {};
                                        if (!this.shouldComponentBeProcessed(component, input)) return [3 /*break*/, 2];
                                        return [4 /*yield*/, this.process(component, processedItem, input)];
                                    case 1: return [2 /*return*/, _a.sent()];
                                    case 2: 
                                    // Skip component processing
                                    return [2 /*return*/, processedItem];
                                }
                            });
                        }); })];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    /**
     * Runs the components of its Pipeline
     */
    Pipeline.prototype.Run = function () {
        return __awaiter(this, void 0, void 0, function () {
            var output;
            var _this = this;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        this.resolveDependencyResolution();
                        output = [];
                        return [4 /*yield*/, p_iteration_1.forEachSeries(this.sortedComponents, function (component) { return __awaiter(_this, void 0, void 0, function () {
                                return __generator(this, function (_a) {
                                    switch (_a.label) {
                                        case 0:
                                            if (!(component.settings.type === pipeline_1.ComponentType.SIMPLE_MAP)) return [3 /*break*/, 2];
                                            return [4 /*yield*/, this.processSimpleMapComponent(component, output)];
                                        case 1:
                                            output = _a.sent();
                                            return [3 /*break*/, 4];
                                        case 2:
                                            if (!(component.settings.type === pipeline_1.ComponentType.ADVANCED_MAP)) return [3 /*break*/, 4];
                                            return [4 /*yield*/, this.process(component, output, this.parsedInput)];
                                        case 3:
                                            output = _a.sent();
                                            _a.label = 4;
                                        case 4: return [2 /*return*/];
                                    }
                                });
                            }); })];
                    case 1:
                        _a.sent();
                        return [2 /*return*/, output];
                }
            });
        });
    };
    return Pipeline;
}());
exports.Pipeline = Pipeline;
//# sourceMappingURL=pipeline.js.map