import { ComponentSettings, IComponent } from './component';
/**
 * Stores a component and its settings
 */
export interface ComponentRegister {
    settings: ComponentSettings;
    component: IComponent;
    id: string;
    dependencies?: ComponentRegister[];
}
/**
 * Factory for registering any component
 */
export declare class ComponentRegistry {
    private components;
    private static instance;
    private areDependenciesAlreadyMapped;
    /**
     * Maps dependencies of a component setting with
     * a component register of this ComponentRegistry.
     */
    private MapDependencies;
    /**
     * Registers the given component with the given settings
     * @param component The component class to register
     * @param settings The settings the component has
     */
    Register(component: IComponent, settings: ComponentSettings): void;
    GetComponentById(componentId: any): ComponentRegister;
    /**
     * Returns all registered components
     */
    readonly Components: ComponentRegister[];
    /**
     * Returns the instance of this registry
     */
    static readonly Instance: ComponentRegistry;
}
