"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Factory for registering any component
 */
var ComponentRegistry = /** @class */ (function () {
    function ComponentRegistry() {
        this.components = [];
        this.areDependenciesAlreadyMapped = false;
    }
    /**
     * Maps dependencies of a component setting with
     * a component register of this ComponentRegistry.
     */
    ComponentRegistry.prototype.MapDependencies = function () {
        var _this = this;
        if (this.areDependenciesAlreadyMapped)
            return;
        this.areDependenciesAlreadyMapped = true;
        (this.components || []).forEach(function (component) {
            return component.dependencies = (component.settings.dependencies || []).map(function (dependency) {
                return _this.GetComponentById(
                // @ts-ignore
                dependency.constructor.name);
            });
        });
    };
    /**
     * Registers the given component with the given settings
     * @param component The component class to register
     * @param settings The settings the component has
     */
    ComponentRegistry.prototype.Register = function (component, settings) {
        this.components.push({
            settings: settings,
            component: component,
            // @ts-ignore
            id: component.constructor.name
        });
    };
    ComponentRegistry.prototype.GetComponentById = function (componentId) {
        return this.components.find(function (component) { return component.id === componentId; });
    };
    Object.defineProperty(ComponentRegistry.prototype, "Components", {
        /**
         * Returns all registered components
         */
        get: function () {
            this.MapDependencies();
            return this.components;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(ComponentRegistry, "Instance", {
        /**
         * Returns the instance of this registry
         */
        get: function () {
            return this.instance || (this.instance = new this());
        },
        enumerable: true,
        configurable: true
    });
    return ComponentRegistry;
}());
exports.ComponentRegistry = ComponentRegistry;
//# sourceMappingURL=registry.js.map