import { Identifyable } from '../../core/identifyable';
export declare class ItemEffect implements Identifyable {
    /**
     * The unique id of the effect
     */
    id: string;
    /**
     * The human readable name of the effect
     */
    name: string;
    /**
     * The effectiveness of the effect in percent
     */
    effectPercent: number;
}
export declare class ItemFood {
    /**
     * Effect of the item (e.g. Berry effect)
     */
    effect: ItemEffect[];
    /**
     * The amount of growth in percent
     */
    growthPercent: number;
    /**
     * Unknown
     */
    berryMultiplier?: number;
    /**
     * Unknown
     */
    remoteBerryMultiplier?: number;
}
export declare class ItemPotion {
    /**
     * The amount of stamina which gets recharged
     */
    staminaAmount: number;
    /**
     * The percent of stamina which gets recharged
     */
    staminaPercent: number;
}
export declare class ItemIncense {
    /**
     * The time the incense is active in seconds
     */
    incenseLifeTimeSceonds: number;
    /**
     * The standing time between encounters in seconds
     */
    standingTimeBetweenEncountersSeconds: number;
    /**
     * The moving time between encounters in seconds
     */
    movingTimeBetweenEncounterSeconds: number;
    /**
     * The distance required for shorter intervals in meters
     */
    distanceRequiredForShorterIntervalMeters: number;
}
export declare class ItemRevive {
    /**
     * The percent of stamina which gets recharged
     */
    staminaPercent: number;
}
export declare class ItemEggIncubinator {
    /**
     * The type of the incubinator
     * e.g. distance
     */
    type: Identifyable;
    /**
     * The amount of uses of the incubinator until its broken
     */
    uses?: number;
    /**
     * The multiplier of the distance in percent
     */
    distanceMultiplier: number;
}
export declare class ItemInventoryUpgrade {
    /**
     * The amount of additional storage
     */
    additionalStorage: number;
    /**
     * The type of the upgrade
     * e.g. Increase Pokemone Storage
     */
    type: Identifyable;
}
export declare class ItemXpBoost {
    /**
     * The xpBoost mulitplier during the duration in percent
     */
    xpMultiplier: number;
    /**
     * The duration of the boost in miliseconds
     */
    boostDurationMs: number;
}
export declare class ItemStardustBoost {
    /**
     * The stardust multiplier during the boost duration in percent
     */
    stardustMultiplier: number;
    /**
     * The boost duration in miliseconds
     */
    boostDurationMs: number;
}
export declare class Item {
    /**
     * The identifier of the item
     */
    id: string;
    /**
     * The human readable name of the item
     */
    name: string;
    /**
     * The category of the item
     * e.g. ITEM_CATEGORY_FOOD
     */
    category: Identifyable;
    /**
     * The level on which level this item gets dropped
     */
    dropTrainerLevel: number;
    /**
     * The type of the item.
     * e.g. Food
     */
    type: Identifyable;
    /**
     * Data of a food item
     */
    food?: ItemFood;
    /**
     * Data of a potion item
     */
    potion?: ItemPotion;
    /**
     * Data of an incense item
     */
    incense?: ItemIncense;
    /**
     * Data of a revive item
     */
    revive?: ItemRevive;
    /**
     * Data of an egg incubinator
     */
    eggIncubinator?: ItemEggIncubinator;
    /**
     * Data of an inventory upgrade
     */
    inventoryUpgrade?: ItemInventoryUpgrade;
    /**
     * Data of a xp boost
     */
    xpBoost?: ItemXpBoost;
    /**
     * Data of a stardust booster
     */
    stardustBoost?: ItemStardustBoost;
}
