"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
var pipeline_1 = require("@core/pipeline");
var enounter_1 = require("./enounter");
var gameMaster = require('@data/GAME_MASTER.json');
var GenderPercentage = /** @class */ (function () {
    function GenderPercentage() {
    }
    GenderPercentage.prototype.isItemTemplateSpawn = function (item) {
        return new RegExp('^(SPAWN_V[0-9]+_POKEMON_?.*)', 'g').test(item.templateId);
    };
    /**
     * Parses the gender-spawn-percentage of the given Pokémon ID)
     * @param {String} id The id of the Pokémon (Example: BULBASAUR)
     * @returns {PokemonGender} Object with the Pokémon Gender Percent values
     */
    GenderPercentage.prototype.getGenderPercent = function (gameMaster, pokemonId) {
        var _this = this;
        var itemTemplate = gameMaster
            .itemTemplates
            .filter(function (itemTemplate) { return _this.isItemTemplateSpawn(itemTemplate); })
            .find(function (itemTemplate) {
            return itemTemplate.genderSettings.pokemon === pokemonId;
        });
        var malePercent = itemTemplate.genderSettings.gender.malePercent;
        var femalePercent = itemTemplate.genderSettings.gender.femalePercent;
        // For NIDORAN_MALE
        if (malePercent === 1) {
            femalePercent = 0;
        }
        // For NIDODRAN_FEMALE
        if (femalePercent === 1) {
            malePercent = 0;
        }
        // No gender
        if (!malePercent && !femalePercent) {
            return null;
        }
        return {
            malePercent: malePercent,
            femalePercent: femalePercent
        };
    };
    GenderPercentage.prototype.Process = function (pokemon, rawPokemon) {
        var gender = this.getGenderPercent(gameMaster, rawPokemon.pokemonSettings.pokemonId);
        if (gender) {
            pokemon.encounter.gender = gender;
        }
        return pokemon;
    };
    GenderPercentage = __decorate([
        pipeline_1.Component({
            pipeline: 'pokemon',
            dependencies: [
                new enounter_1.Encounter()
            ]
        })
    ], GenderPercentage);
    return GenderPercentage;
}());
exports.GenderPercentage = GenderPercentage;
//# sourceMappingURL=genderPercentage.js.map