"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
var component_1 = require("@core/pipeline/component");
var genericPropertyMapper_1 = require("../genericPropertyMapper");
var pokemonEvolution_1 = require("./pokemonEvolution");
var _util_1 = require("@util");
var id_1 = require("../id");
var templateIdToId_1 = require("../shared/templateIdToId");
var getPokemonIdByEvolutionBranch_1 = require("./shared/getPokemonIdByEvolutionBranch");
var getEvolutionItemRequirement_1 = require("./shared/getEvolutionItemRequirement");
var FutureBranches = /** @class */ (function () {
    /**
     * Parses the future evolutions
     */
    function FutureBranches() {
    }
    /**
     * Returns the future evolutions from the given GAME_MASTER data.
     * @param pokemonId The id of the pokemon
     */
    FutureBranches.prototype.GetFutureRawEvolutions = function (pokemon) {
        var _this = this;
        return (pokemon.pokemonSettings.evolutionBranch || []).map(function (branch) {
            var pokemonId = getPokemonIdByEvolutionBranch_1.getPokemonIdByEvolutionBranch(branch);
            var rawPokemon = _this.GetRawPokemonById(pokemonId);
            return rawPokemon;
        });
    };
    /**
     * Returns the cost for the evolution of the Pokemon
     * @param pokemonId The id of the pokemon you want to have the evolution cost
     * @param rawPokemon The GAME_MASTER provided raw pokemon of the lower evolution branch
     */
    FutureBranches.prototype.GetEvolutionCost = function (futurePokemonId, rawPokemon) {
        var evolutionBranch = (rawPokemon.pokemonSettings.evolutionBranch || [])
            .find(function (branch) { return getPokemonIdByEvolutionBranch_1.getPokemonIdByEvolutionBranch(branch) === futurePokemonId; });
        // If no evolution is found, just return nothing
        if (!evolutionBranch) {
            return;
        }
        // Make evolutionItemRequirement to Identifyable
        var evolutionItem;
        if (evolutionBranch.evolutionItemRequirement) {
            evolutionItem = getEvolutionItemRequirement_1.GetEvolutionItemRequirement(evolutionBranch.evolutionItemRequirement);
        }
        // Return evolutionCost Object
        return {
            candyCost: evolutionBranch.candyCost,
            kmBuddyDistance: evolutionBranch.kmBuddyDistanceRequirement,
            evolutionItem: evolutionItem ? evolutionItem : undefined,
        };
    };
    /**
     * Get the raw GAME_MASTER pokemon by id
     * @param pokemonId The pokemon id
     */
    FutureBranches.prototype.GetRawPokemonById = function (pokemonId) {
        return this.rawPokemons.find(function (pokemon) { return templateIdToId_1.TemplateIdToId(pokemon) === pokemonId; });
    };
    /**
     * Recursively gets all future branches from the given pokemon
     * @param pokemonId The id of the pokemon
     */
    FutureBranches.prototype.GetFutureBranches = function (rawPokemon) {
        var _this = this;
        var futurePokemons = this.GetFutureRawEvolutions(rawPokemon);
        if (!futurePokemons.length) {
            return undefined;
        }
        return futurePokemons
            .filter(function (pokemon) { return pokemon !== undefined; })
            .map(function (futurePokemon) { return (__assign({}, _util_1.Util.SnakeCase2Identifyable(templateIdToId_1.TemplateIdToId(futurePokemon)), { futureBranches: _this.GetFutureBranches(futurePokemon), costToEvolve: _this.GetEvolutionCost(templateIdToId_1.TemplateIdToId(futurePokemon), rawPokemon) })); });
    };
    FutureBranches.prototype.Process = function (pokemons, rawPokemons) {
        var _this = this;
        this.rawPokemons = rawPokemons;
        return pokemons.map(function (pokemon) {
            var rawPokemon = _this.GetRawPokemonById(pokemon.id);
            pokemon.evolution.futureBranches = _this.GetFutureBranches(rawPokemon);
            return pokemon;
        });
    };
    FutureBranches = __decorate([
        component_1.Component({
            pipeline: 'pokemon',
            type: component_1.ComponentType.ADVANCED_MAP,
            dependencies: [
                new id_1.Id(),
                new genericPropertyMapper_1.GenericPropertyMapper(),
                new pokemonEvolution_1.PokemonEvolutionParser(),
            ]
        })
        /**
         * Parses the future evolutions
         */
    ], FutureBranches);
    return FutureBranches;
}());
exports.FutureBranches = FutureBranches;
//# sourceMappingURL=futureBranches.js.map