"use strict";
var __assign = (this && this.__assign) || Object.assign || function(t) {
    for (var s, i = 1, n = arguments.length; i < n; i++) {
        s = arguments[i];
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
            t[p] = s[p];
    }
    return t;
};
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
var component_1 = require("@core/pipeline/component");
var genericPropertyMapper_1 = require("../genericPropertyMapper");
var pokemonEvolution_1 = require("./pokemonEvolution");
var index_1 = require("@util/index");
var id_1 = require("../id");
var templateIdToId_1 = require("../shared/templateIdToId");
var getPokemonIdByEvolutionBranch_1 = require("./shared/getPokemonIdByEvolutionBranch");
var getEvolutionItemRequirement_1 = require("./shared/getEvolutionItemRequirement");
var PastBranches = /** @class */ (function () {
    /**
     * Parses the past evolutions
     */
    function PastBranches() {
    }
    /**
     * Get the raw GAME_MASTER pokemon by id
     * @param pokemonId The pokemon id
     */
    PastBranches.prototype.GetRawPokemonById = function (pokemonId) {
        return this.rawPokemons.find(function (pokemon) { return templateIdToId_1.TemplateIdToId(pokemon) === pokemonId; });
    };
    /**
     * Returns the previous evolution from the given GAME_MASTER data.
     * @param pokemonId The id of the pokemon
     */
    PastBranches.prototype.GetPreviousRawEvolution = function (pokemonId) {
        return this.rawPokemons.find(function (item) {
            return (item.pokemonSettings.evolutionBranch || [])
                .some(function (evolution) { return getPokemonIdByEvolutionBranch_1.getPokemonIdByEvolutionBranch(evolution) === pokemonId; });
        });
    };
    /**
     * Returns the cost for the evolution of the Pokemon
     * @param pokemonId The id of the pokemon you want to have the evolution cost
     * @param rawPokemon The GAME_MASTER provided raw pokemon of the lower evolution branch
     */
    PastBranches.prototype.GetEvolutionCost = function (pokemonId, rawPokemon) {
        if (!rawPokemon)
            return undefined;
        var evolutionBranch = rawPokemon.pokemonSettings.evolutionBranch
            .find(function (evolution) { return getPokemonIdByEvolutionBranch_1.getPokemonIdByEvolutionBranch(evolution) === pokemonId; });
        // Make evolutionItemRequirement to Identifyable
        var evolutionItem;
        if (evolutionBranch.evolutionItemRequirement) {
            evolutionItem = getEvolutionItemRequirement_1.GetEvolutionItemRequirement(evolutionBranch.evolutionItemRequirement);
        }
        return {
            candyCost: evolutionBranch.candyCost,
            kmBuddyDistance: evolutionBranch.kmBuddyDistanceRequirement,
            evolutionItem: evolutionItem,
        };
    };
    /**
     * Recursively gets all past branches from the given pokemon
     * @param pokemonId The id of the pokemon
     * @param rawPokemons All raw GAME_MASTER pokemons
     */
    PastBranches.prototype.GetPastBranch = function (pokemonId) {
        var pastPokemon = this.GetPreviousRawEvolution(pokemonId);
        if (!pastPokemon) {
            return undefined;
        }
        var rawPastPokemon = this.GetPreviousRawEvolution(templateIdToId_1.TemplateIdToId(pastPokemon));
        var costToEvolve = this.GetEvolutionCost(templateIdToId_1.TemplateIdToId(pastPokemon), rawPastPokemon);
        var pastBranch = this.GetPastBranch(templateIdToId_1.TemplateIdToId(pastPokemon));
        return __assign({}, index_1.Util.SnakeCase2Identifyable(templateIdToId_1.TemplateIdToId(pastPokemon)), { pastBranch: pastBranch,
            costToEvolve: costToEvolve });
    };
    PastBranches.prototype.Process = function (pokemons, rawPokemons) {
        var _this = this;
        this.rawPokemons = rawPokemons;
        return pokemons.map(function (pokemon) {
            pokemon.evolution.pastBranch = _this.GetPastBranch(pokemon.id);
            var previousEvolution = _this.GetPreviousRawEvolution(pokemon.id);
            if (previousEvolution) {
                pokemon.evolution.costToEvolve = _this.GetEvolutionCost(pokemon.id, previousEvolution);
            }
            return pokemon;
        });
    };
    PastBranches = __decorate([
        component_1.Component({
            pipeline: 'pokemon',
            type: component_1.ComponentType.ADVANCED_MAP,
            dependencies: [
                new id_1.Id(),
                new genericPropertyMapper_1.GenericPropertyMapper(),
                new pokemonEvolution_1.PokemonEvolutionParser(),
            ]
        })
        /**
         * Parses the past evolutions
         */
    ], PastBranches);
    return PastBranches;
}());
exports.PastBranches = PastBranches;
//# sourceMappingURL=pastBranches.js.map