"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var _util_1 = require("@util");
var gameMaster = require('@data/GAME_MASTER.json');
/**
 * Returns the identify-able object of the evolution item
 * @param evolutionItemRequirement The evolutionItemRequirement as string or number
 *
 * @example
 * GetEvolutionItemRequirement(1106) // returns { id: "ITEM_GEN4_EVOLUTION_STONE", name: "Gen4 Evolution Stone" }
 * GetEvolutionItemRequirement("ITEM_GEN4_EVOLUTION_STONE") // returns { id: "ITEM_GEN4_EVOLUTION_STONE", name: "Gen4 Evolution Stone" }
 */
exports.GetEvolutionItemRequirement = function (evolutionItemRequirement) {
    var id;
    // If is number then it is an item id..
    if (typeof evolutionItemRequirement === 'number') {
        // Find item with the given id
        var foundItem = gameMaster.itemTemplates
            .find(function (item) { return item.itemSettings && item.itemSettings.itemId.toString() === evolutionItemRequirement.toString(); });
        id = foundItem.templateId;
    }
    else {
        // If is string, it already is the id
        id = evolutionItemRequirement;
    }
    var name = _util_1.Util.SnakeCase2HumanReadable(id.replace('ITEM_', ''));
    return { id: id, name: name };
};
//# sourceMappingURL=getEvolutionItemRequirement.js.map