"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
var pipeline_1 = require("@core/pipeline");
var app_1 = require("@settings/app");
var MaxCP = /** @class */ (function () {
    function MaxCP() {
    }
    /**
     * Calculates the maximum CP amount of the given
     * Stamina, Attack and Defense values.
     * Formula source: https://www.reddit.com/r/TheSilphRoad/comments/4t7r4d/exact_pokemon_cp_formula/
     *
     * @param {Number} baseStamina The base stamina of the Pokemon
     * @param {Number} baseAttack The base attack of the Pokemon
     * @param {Number} baseDefense The base defemse of the Pokemon
     *
     * @returns {Number} The maximum CP amount of the given values
     */
    MaxCP.prototype.Calculate = function (baseStamina, baseAttack, baseDefense) {
        // Stamina = (BaseStamina + IndividualStamina) * TotalCPMultiplier
        var stamina = (baseStamina + app_1.default.MAX_INDIVIDUAL_STAMINA) * app_1.default.MAX_CP_MULTIPLIER;
        // Attack = (BaseAttack + IndividualAttack) * TotalCpMultiplier
        var attack = (baseAttack + app_1.default.MAX_INDIVIDUAL_ATTACK) * app_1.default.MAX_CP_MULTIPLIER;
        // Defense = (BaseDefense + IndividualDefense) * TotalCpMultiplier
        var defense = (baseDefense + app_1.default.MAX_INDIVIDUAL_DEFENSE) * app_1.default.MAX_CP_MULTIPLIER;
        // CP = MAX(10, FLOOR(Stamina^0.5 * Attack * Def^0.5 / 10))
        return Math.max(10, Math.floor(Math.pow(stamina, 0.5) * attack * Math.pow(defense, 0.5) / 10));
    };
    /**
     * Calculates the max CP of a Pokemon
     */
    MaxCP.prototype.Process = function (pokemon, rawPokemon) {
        pokemon.maxCP = this.Calculate(rawPokemon.pokemonSettings.stats.baseStamina, rawPokemon.pokemonSettings.stats.baseAttack, rawPokemon.pokemonSettings.stats.baseDefense);
        return pokemon;
    };
    MaxCP = __decorate([
        pipeline_1.Component({
            pipeline: 'pokemon'
        })
    ], MaxCP);
    return MaxCP;
}());
exports.MaxCP = MaxCP;
//# sourceMappingURL=maxCP.js.map